@@ -10,12 +10,26 @@ import torchvision
 import numpy as np
 import omegaconf
 import PIL
+from PIL import Image
 from omegaconf import OmegaConf
-from forks.taming_transformers.taming.models.vqgan import VQModel
+from forks.taming_transformers.taming.models.vqgan import VQModel, GumbelVQ
 from bigotis.modeling_utils import ImageGenerator
 
 logging.basicConfig(format='%(message)s', level=logging.INFO)
 
+VQGAN_CKPT_DICT = {
+    "imagenet-16384":
+    r"https://heibox.uni-heidelberg.de/d/a7530b09fed84f80a887/files/?p=%2Fckpts%2Flast.ckpt&dl=1",
+    "openimages-8192":
+    r"https://heibox.uni-heidelberg.de/d/2e5662443a6b4307b470/files/?p=%2Fckpts%2Flast.ckpt&dl=1",
+}
+VQGAN_CONFIG_DICT = {
+    "imagenet-16384":
+    r"https://raw.githubusercontent.com/vipermu/taming-transformers/master/configs/imagenet-16384.yaml",
+    "openimages-8192":
+    r"https://raw.githubusercontent.com/vipermu/taming-transformers/master/configs/openimages-8192.yaml",
+}
+
 
 class TamingDecoder(ImageGenerator):
     """
@@ -26,6 +40,7 @@ class TamingDecoder(ImageGenerator):
     def __init__(
         self,
         device: str = 'cuda',
+        model_name: str = "imagenet-16384",
     ) -> None:
         """
         Downloads the VQGAN model and loads a pre-defined 
@@ -43,9 +58,10 @@ class TamingDecoder(ImageGenerator):
         modeling_cache_dir = os.path.join(modeling_dir, ".modeling_cache")
         os.makedirs(modeling_cache_dir, exist_ok=True)
 
-        modeling_ckpt_path = os.path.join(modeling_cache_dir, 'last.ckpt')
+        modeling_ckpt_path = os.path.join(modeling_cache_dir,
+                                          f'{model_name}.ckpt')
         if not os.path.exists(modeling_ckpt_path):
-            modeling_ckpt_url = 'https://heibox.uni-heidelberg.de/f/867b05fc8c4841768640/?dl=1'
+            modeling_ckpt_url = VQGAN_CKPT_DICT[model_name]
 
             logging.info(
                 f"Downloading pre-trained weights for VQ-GAN from {modeling_ckpt_url}"
@@ -56,12 +72,13 @@ class TamingDecoder(ImageGenerator):
                 ckpt_file.write(results.content)
 
         # TODO: update the url with our own config using the correct paths
-        modeling_config_path = os.path.join(modeling_cache_dir, 'model.yaml')
+        modeling_config_path = os.path.join(modeling_cache_dir,
+                                            f'{model_name}.yaml')
         if not os.path.exists(modeling_config_path):
-            modeling_config_url = 'https://raw.githubusercontent.com/vipermu/taming-transformers/master/configs/custom_vqgan.yaml'
+            modeling_config_url = VQGAN_CONFIG_DICT[model_name]
 
             logging.info(
-                "Downloading `model.yaml` from vipermu taming-transformers fork"
+                f"Downloading `{model_name}.yaml` from vipermu taming-transformers fork"
             )
             results = requests.get(modeling_config_url, allow_redirects=True)
 
@@ -118,7 +135,10 @@ class TamingDecoder(ImageGenerator):
             VQModel: 
                 loaded VQGAN model.
         """
-        model = VQModel(**config.model.params)
+        if "GumbelVQ" in config.model.target:
+            model = GumbelVQ(**config.model.params)
+        else:
+            model = VQModel(**config.model.params)
 
         if ckpt_path is not None:
             # XXX: check wtf is going on here
@@ -243,19 +263,15 @@ class TamingDecoder(ImageGenerator):
             z_logits = init_embed.to(self.device)
 
         elif init_img_path is not None:
-            init_img = self.load_img(init_img_path, )
-            init_img = init_img * 2 - 1
-
-            init_img = init_img.permute(0, 3, 1, 2)
-
-            # clip_img_z_logits = self.get_clip_img_encodings(init_img)
-            # clip_img_z_logits = clip_img_z_logits.detach().clone()
-
-            z, _, [_, _, _indices] = self.vqgan_model.encode(init_img)
+            init_img = Image.open(init_img_path, )
+            init_img = init_img.resize((target_img_height, target_img_width))
+            z = self.get_latents_from_img(init_img)
 
             z_logits = z.to(self.device)
 
-            # img_z_logits = z.detach().clone()
+            logging.warn(
+                f"TARGET RES CHANGED TO {target_img_height}x{target_img_width}"
+            )
 
         else:
             z_logits = self.get_random_latents(
@@ -478,15 +494,15 @@ class TamingDecoder(ImageGenerator):
 
 
 if __name__ == '__main__':
-    target_img_height = 50
-    target_img_width = 400
+    target_img_height = 256
+    target_img_width = 256
     prompt = "A pink dog"
-    lr = 0.5
+    lr = 0.1
     num_steps = 200
     num_augmentations = 128
     loss_type = 'cosine_similarity'
     init_img_path = None
-    # init_img_path = "alien.png"
+    # init_img_path = "tree.jpg"
     loss_clip_value = None
 
     taming_decoder = TamingDecoder()
